0.7.0 (2013-10-05)
------------------

* Move the repository to github
* Add example project
* Add unit tests
* Improvements in the code (for each branch)
* Improvements in the patches (for each branch
* Integration with `Travis <https://travis-ci.org/goinnn/django-smart-extends>`_
* Details

0.6 (2012-11-07)
----------------

* Compatible with Django 1.4 (need Django patches when DEBUG_TEMPLATE is False)

0.5.1 (2011-12-03)
------------------

* Compatible with Django 1.2 and Django 1.3 (need Django patches when DEBUG_TEMPLATE is False)

0.5.0 (2011-01-11)
------------------

* Initial version
